<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AutoUpdater</name>
    <message>
        <source>No ssl configuration!
OpenSSL might not be installed.</source>
        <translation>SSL yapılandırması yok!
OpenSSL yüklenmemiş olabilir.</translation>
    </message>
    <message>
        <source>Failed to save the Birdtray installer:
</source>
        <translation>Birdtray yükleyici kaydedilemedi:
</translation>
    </message>
    <message>
        <source>Failed to download the Birdtray installer:
</source>
        <translation>Birdtray yükleyici indirilemedi:
</translation>
    </message>
    <message>
        <source>Installer download failed</source>
        <translation>Yükleyici indirilemedi</translation>
    </message>
    <message>
        <source>Update failed</source>
        <translation>Güncelleştirme başarısız</translation>
    </message>
    <message>
        <source>Failed to start the Birdtray installer.</source>
        <translation>Birdtray yükleyici başlatılamadı.</translation>
    </message>
</context>
<context>
    <name>BirdtrayApp</name>
    <message>
        <source>Display the contents of the given mork database.</source>
        <translation>Verilen mork veritabanının içeriğini görüntüleyin.</translation>
    </message>
    <message>
        <source>databaseFile</source>
        <translation>veritabanıDosyası</translation>
    </message>
    <message>
        <source>Decode an IMAP Utf7 string.</source>
        <translation>IMAP Utf7 dizesinin kodunu çözün.</translation>
    </message>
    <message>
        <source>string</source>
        <translation>dizi</translation>
    </message>
    <message>
        <source>Show the settings.</source>
        <translation>Ayarları gösterin.</translation>
    </message>
    <message>
        <source>Reset the settings to the defaults.</source>
        <translation>Ayarları varsayılanlara sıfırlayın.</translation>
    </message>
    <message>
        <source>Toggle the Thunderbird window.</source>
        <translation>Thunderbird penceresini aç/kapa.</translation>
    </message>
    <message>
        <source>Show the Thunderbird window.</source>
        <translation>Thunderbird penceresini göster.</translation>
    </message>
    <message>
        <source>Hide the Thunderbird window.</source>
        <translation>Thunderbird penceresini gizleyin.</translation>
    </message>
    <message>
        <source>Write log to a file.</source>
        <translation>Log&apos;u bir dosyaya yazın.</translation>
    </message>
    <message>
        <source>A free system tray notification for new mail for Thunderbird.</source>
        <translation>Thunderbird&apos;den yeni postalar için ücretsiz bir sistem tepsisi bildirim programı.</translation>
    </message>
    <message>
        <source>file</source>
        <translation>dosya</translation>
    </message>
    <message>
        <source>Sorry, the system tray cannot be controlled by this add-on on your operating system.</source>
        <translation>Üzgünüz, sistem tepsisi işletim sisteminizdeki bu eklenti üzerinden kontrol edilemez.</translation>
    </message>
</context>
<context>
    <name>DialogAddEditNewEmail</name>
    <message>
        <source>&quot;New Email&quot; Entry</source>
        <translation>&quot;Yeni E-posta&quot; Girişi</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <source>(Optional) Prefilled fields</source>
        <translation>(İsteğe bağlı) Önceden doldurulmuş alanlar</translation>
    </message>
    <message>
        <source>Email subject:</source>
        <translation>E-posta konu:</translation>
    </message>
    <message>
        <source>Email message text:</source>
        <translation>E-posta mesajı metni:</translation>
    </message>
    <message>
        <source>Email recipient:</source>
        <translation>E-posta alıcısı:</translation>
    </message>
    <message>
        <source>No name specified</source>
        <translation>İsim belirtilmedi</translation>
    </message>
    <message>
        <source>The name cannot be empty.</source>
        <translation>İsim boş olamaz.</translation>
    </message>
</context>
<context>
    <name>DialogLogOutput</name>
    <message>
        <source>Debug log viewer</source>
        <translation>Hata ayıklama günlük görüntüleyicisi</translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <source>Birdtray Settings</source>
        <translation>Birdtray Ayarları</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>New Mail Notification</source>
        <translation>Yeni Posta Bildirimi</translation>
    </message>
    <message>
        <source>Show unread count</source>
        <translation>Okunmamış sayıyı göster</translation>
    </message>
    <message>
        <source>Different icon when unread:</source>
        <translation>Okunmadığında farklı simge:</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Kapalı</translation>
    </message>
    <message>
        <source>Fastest</source>
        <translation>En hızlı</translation>
    </message>
    <message>
        <source>Icon (Ctrl-click to reset):</source>
        <translation>Simge (sıfırlamak için Ctrl
tuşunu basılı tutarak tıklayın):</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This notification color will be used when more than one monitored account has unread emails.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multiple notification color:</source>
        <translation>Çoklu bildirim rengi:</translation>
    </message>
    <message>
        <source>Blinking speed:</source>
        <translation>Yanıp sönme hızı:</translation>
    </message>
    <message>
        <source>Font style:</source>
        <translation>Yazı stili:</translation>
    </message>
    <message>
        <source>Bold:</source>
        <translation>Kalın:</translation>
    </message>
    <message>
        <source>Notification border color:</source>
        <translation>Bildirim kenarlığı rengi:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Genişlik:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>Monitoring</source>
        <translation>İzleme</translation>
    </message>
    <message>
        <source>Accounts to monitor</source>
        <translation>İzlenecek hesaplar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Allow ignoring the current unread email counter</source>
        <translation>Mevcut okunmamış e-posta sayacının yok sayılmasına izin ver</translation>
    </message>
    <message>
        <source>Hiding</source>
        <translation>Gizleniyor</translation>
    </message>
    <message>
        <source>Launching and Hiding</source>
        <translation>Başlatma ve Gizleme</translation>
    </message>
    <message>
        <source>Start Thunderbird when Birdtray starts</source>
        <translation>Birdtray başladığında Thunderbird&apos;ü başlatın</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;When both Thunderbird and Birdtray are set to start with the operating system, this usually results in two copies of Thunderbird being launched. Here you can add a delay before Thunderbird is launched, to prevent this.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> second delay</source>
        <translation> ikinci gecikme</translation>
    </message>
    <message>
        <source>with a </source>
        <translation>birlikte </translation>
    </message>
    <message>
        <source>and hide it</source>
        <translation>ve sakla</translation>
    </message>
    <message>
        <source>Terminate Thunderbird when quitting Birdtray</source>
        <translation>Birdtray&apos;den çıkarken Thunderbird&apos;ü sonlandırın</translation>
    </message>
    <message>
        <source>Hide/show Thunderbird window when clicking on tray icon</source>
        <translation>Tepsi simgesine tıklandığında Thunderbird penceresini gizle / göster</translation>
    </message>
    <message>
        <source>Hide Thunderbird window when it is minimized</source>
        <translation>Simge durumuna küçültüldüğünde Thunderbird penceresini gizle</translation>
    </message>
    <message>
        <source>Show red X in tray icon if Thunderbird is not running</source>
        <translation>Thunderbird çalışmıyorsa tepsi simgesinde kırmızı X göster</translation>
    </message>
    <message>
        <source>Restart Thunderbird if it was closed</source>
        <translation>Kapalıysa Thunderbird&apos;ü yeniden başlat</translation>
    </message>
    <message>
        <source>New Email</source>
        <translation>Yeni E-posta</translation>
    </message>
    <message>
        <source>Enable New Email submenu</source>
        <translation>Yeni E-posta alt menüsünü etkinleştir</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <source>Please do not change these settings unless you understand what you&apos;re doing.</source>
        <translation>Lütfen ne yaptığınızı anlamadıkça bu ayarları değiştirmeyin.</translation>
    </message>
    <message>
        <source>Thunderbird window name pattern:</source>
        <translation>Thunderbird pencere adı kalıbı:</translation>
    </message>
    <message>
        <source>Minimum notification font size:</source>
        <translation>Minimum bildirim yazı tipi boyutu:</translation>
    </message>
    <message>
        <source> points</source>
        <translation> puan</translation>
    </message>
    <message>
        <source>When blinking, use the fade-in/fade-out transition (increases CPU use!)</source>
        <translation>Yanıp sönerken, fade-in / fade-out geçişini kullanın (CPU kullanımını artırır!)</translation>
    </message>
    <message>
        <source>Make the system tray icon</source>
        <translation>Sistem tepsisi simgesini yapın</translation>
    </message>
    <message>
        <source>Check for new updates on startup</source>
        <translation>Başlangıçta yeni güncellemeleri kontrol edin</translation>
    </message>
    <message>
        <source>Check now</source>
        <translation>Şimdi kontrol et</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Version check failed</source>
        <translation>Sürüm kontrolü başarısız oldu</translation>
    </message>
    <message>
        <source>Failed to check for a new Birdtray version:
</source>
        <translation>Yeni Birdtray sürümü kontrol edilemedi:
</translation>
    </message>
    <message>
        <source>Checking...</source>
        <translation>Kontrol ediliyor...</translation>
    </message>
    <message>
        <source>Choose the new icon</source>
        <translation>Yeni simgeyi seçin</translation>
    </message>
    <message>
        <source>Images (*.png *.svg *.svgz)</source>
        <translation>Resimler (*.png *.svg *.svgz)</translation>
    </message>
    <message>
        <source>Invalid icon</source>
        <translation>Geçersiz simge</translation>
    </message>
    <message>
        <source>Could not load the icon from this file.</source>
        <translation>Simge bu dosyadan yüklenemedi.</translation>
    </message>
    <message>
        <source>Thunderbird command line:</source>
        <translation>Thunderbird komut satırı:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This is the full command-line (with arguments) which will be used to start Thunderbird. Arguments are space-separated, but spaces in quotes are allowed, i.e. something like &lt;span style=&quot; font-weight:600;&quot;&gt;&amp;quot;C:\Program Files\tb.exe&amp;quot; --profile test&lt;/span&gt; will work.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore all unread email that are present when Birdtray starts. Only new emails will be taken into account by the unread counter.</source>
        <translation>Birdtray başladığında mevcut olan tüm okunmamış e-postaları yoksayın. Okunmamış sayaç tarafından yalnızca yeni e-postalar dikkate alınacaktır.</translation>
    </message>
    <message>
        <source>opaque when new mail is present,</source>
        <translation>yeni posta mevcut olduğunda opak,</translation>
    </message>
    <message>
        <source>hide it if no new mail is present.</source>
        <translation>yeni posta yoksa gizleyin.</translation>
    </message>
    <message>
        <source>Choose one or more MSF files</source>
        <translation>Bir veya daha fazla MSF dosyası seçin</translation>
    </message>
    <message>
        <source>Mail Index (*.msf)</source>
        <translation>Posta Dizini (*.msf)</translation>
    </message>
    <message>
        <source>No new updates found</source>
        <translation>Yeni bir güncelleme bulunamadı</translation>
    </message>
    <message>
        <source>Show log window</source>
        <translation>Log penceresini göster</translation>
    </message>
    <message>
        <source>Force index file re-read every</source>
        <translation>Dizin dosyasını her defasında yeniden okumaya zorla</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation> saniye</translation>
    </message>
    <message>
        <source>Translations are powered by the community:</source>
        <translation>Çeviriler topluluk tarafından desteklenmektedir:</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Çevirmenler</translation>
    </message>
    <message>
        <source>Active maintainers</source>
        <translation>Aktif geliştiriciler</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>Destekçiler</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If this box is checked, the Birdtray icon will show the number of unread emails.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;If it is unchecked, no count will be shown, and you will only know about unread emails because of the blinking or different icon, depending on your settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unread change cmd:</source>
        <translation>Okunmamış değişiklik cmd&apos;si:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select mail folders for watching.&lt;br/&gt;&lt;br/&gt;If the dialog doesn&apos;t show your folder, &lt;i&gt;Ctrl + Shift click&lt;/i&gt; to open a file selection dialog that allows adding any mork file.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not load the icon from this file. Try loading the icon in an image editing tool and saving it in a different format.</source>
        <translation>Simge bu dosyadan yüklenemedi. Simgeyi bir görüntü düzenleme aracına yüklemeyi ve farklı bir formatta kaydetmeyi deneyin.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This changes the font thickness, i.e. makes the font bold.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If not empty, this command will be invoked every time the unread counter changes (including when it becomes zero). It is invoked via shell, as-is, with %NEW% replaced by the new unread count value and %OLD% replaced with the old unread count value (which may be the same as new).&lt;/p&gt;&lt;p&gt;Most users don&apos;t need this functionality and should leave it empty.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for new updates when Birdtray starts.</source>
        <translation>Birdtray başladığında yeni güncellemeleri kontrol edin.</translation>
    </message>
    <message>
        <source>Check for a new Birdtray version.</source>
        <translation>Yeni Birdtray sürümünü kontrol edin.</translation>
    </message>
    <message>
        <source>Support non-NETWM compliant WMs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your desktop manager is not fully NETWM compliant, you may need to check this checkbox so it can detect Thunderbird window and is able to minimise and hide it.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When hiding Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When showing Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If enabled, this option adds the &amp;quot;Ignore currently unread emails&amp;quot; action to the context menu. This action allows you to ignore the emails which are currently unread. Birdtray would then pretend there are no unread emails left, and would only show new emails over the ignored count.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;For example, if there were 10 unread emails, and you clicked on &amp;quot;Ignore&amp;quot; action, Birdtray will show no unread email indicator as long as unread email count remains at 10. Once new email is received and you have 11 total unread emails, Birdtray will show the new email count as 1.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Thunderbird by clicking on the tray icon if it was closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When detecting a change, wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> milliseconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>before updating the unread counter.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird process name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Birdtray version [VERSION] compiled at [DATE] using Qt [QT_VERSION].&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Copyright (C) 2018 by George Yunaev, &lt;/span&gt;&lt;a href=&quot;mailto:gyunaev@ulduzsoft.com&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;gyunaev@ulduzsoft.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Birdtray is FREE SOFTWARE, which is licensed under General Public License v3. To clarify further, you can use it for any purpose, including commercial, without paying anything. &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;To ask for help, request a feature or report a bug use the &lt;/span&gt;&lt;a href=&quot;https://github.com/gyunaev/birdtray&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;Github project page&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;For those of you who appreciate my work on Birdtray, which is being developed in my free time, you can do it here: &lt;/span&gt;&lt;a href=&quot;https://paypal.me/ulduzsoft&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;https://paypal.me/ulduzsoft&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Thank you for your continuous support!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Log</name>
    <message>
        <source>Fatal</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Fatal error: %1

Log file is written into file %2</source>
        <translation>Kritik hata: %1

Log dosyası %2 dosyasına yazıldı</translation>
    </message>
    <message>
        <source>Failed to open log file %1: %2</source>
        <translation>Log dosyası açılamadı %1: %2</translation>
    </message>
</context>
<context>
    <name>MailAccountDialog</name>
    <message>
        <source>Choose the Thunderbird profiles path</source>
        <translation>Thunderbird profilleri yolunu seçin</translation>
    </message>
    <message>
        <source>No folder selected</source>
        <translation>Klasör seçilmedi</translation>
    </message>
    <message>
        <source>No mail folder was selected to monitor.
Do you want to continue?</source>
        <translation>İzlenecek posta klasörü seçilmedi.
Devam etmek istiyor musun?</translation>
    </message>
    <message>
        <source>Select Accounts</source>
        <translation>Hesapları Seçin</translation>
    </message>
    <message>
        <source>Select the directory that contains the Thunderbird profiles.</source>
        <translation>Thunderbird profillerini içeren dizini seçin.</translation>
    </message>
    <message>
        <source>Thunderbird Profiles Directory</source>
        <translation>Thunderbird Profilleri Dizini</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gözat</translation>
    </message>
    <message>
        <source>Select the mail accounts you want to monitor.</source>
        <translation>İzlemek istediğiniz posta hesaplarını seçin.</translation>
    </message>
    <message>
        <source>Email Folder</source>
        <translation>E-posta Klasörü</translation>
    </message>
    <message>
        <source>Notification Color</source>
        <translation>Bildirim Rengi</translation>
    </message>
    <message>
        <source>If you monitor multiple folders, the default notification color is used to show the sum of all unread mails.</source>
        <translation>Birden fazla klasörü izliyorsanız, okunmamış tüm postaların toplamını göstermek için varsayılan bildirim rengi kullanılır.</translation>
    </message>
    <message>
        <source>%1 (Profile)</source>
        <translation>%1 (Profıl)</translation>
    </message>
    <message>
        <source>No mail profiles were found.
Please make sure you selected the correct profiles directory.</source>
        <translation>Posta profili bulunamadı.
Lütfen doğru profiller dizinini seçtiğinizden emin olun.</translation>
    </message>
</context>
<context>
    <name>ModelAccountTree</name>
    <message>
        <source>Account</source>
        <translation>Hesap</translation>
    </message>
    <message>
        <source>Notification color</source>
        <translation>Bildirim rengi</translation>
    </message>
</context>
<context>
    <name>ModelNewEmails</name>
    <message>
        <source>Menu entry item</source>
        <translation>Menü giriş öğesi</translation>
    </message>
</context>
<context>
    <name>MorkParser</name>
    <message>
        <source>Couldn&apos;t open file: </source>
        <translation>Dosya açılamadı: </translation>
    </message>
    <message>
        <source>Unsupported version.</source>
        <translation>Desteklenmeyen sürüm.</translation>
    </message>
    <message>
        <source>Invalid format.</source>
        <translation>Geçersiz format.</translation>
    </message>
    <message>
        <source>Parsing error.</source>
        <translation>Ayrıştırma hatası.</translation>
    </message>
    <message>
        <source>Unexpected EOF.</source>
        <translation>Beklenmeyen EOF.</translation>
    </message>
    <message>
        <source>Invalid comment.</source>
        <translation>Geçersiz yorum.</translation>
    </message>
    <message>
        <source>Format error.</source>
        <translation>Format hatası.</translation>
    </message>
    <message>
        <source>Unexpected end of group.</source>
        <translation>Grubun beklenmedik sonu.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Could not save the settings</source>
        <translation>Ayarlar kaydedilemedi</translation>
    </message>
    <message>
        <source>Could not save the settings into file %1:
%2</source>
        <translation>Ayarlar %1 dosyasına kaydedilemedi:
%2</translation>
    </message>
    <message>
        <source>Sqlite based accounts migrated</source>
        <translation>Sqlite tabanlı hesaplar birleştirildi</translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail folders using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser, but some configured mail folders could not be found.</source>
        <translation>Sqlite ayrıştırıcısını kullanarak bir veya daha fazla posta klasörünün izlenmesini yapılandırmıştınız. Bu yöntem kaldırılmıştır. Yapılandırmalarınız Mork ayrıştırıcısına taşındı, ancak yapılandırılmış bazı posta klasörleri bulunamadı.</translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail accounts using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser. Please verify that all accounts were mapped correctly.</source>
        <translation>Sqlite ayrıştırıcısını kullanarak bir veya daha fazla posta hesabının izlenmesini yapılandırmıştınız. Bu yöntem kaldırılmıştır. Konfigürasyonlarınız Mork ayrıştırıcısına taşındı. Lütfen tüm hesapların doğru şekilde eşlendiğini doğrulayın.</translation>
    </message>
    <message>
        <source>Cannot load default system tray icon.</source>
        <translation>Varsayılan sistem tepsisi simgesi yüklenemiyor.</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Would you like to set up Birdtray?</source>
        <translation>Birdtray&apos;i kurmak ister misiniz?</translation>
    </message>
    <message>
        <source>You have not yet configured any email folders to monitor. Would you like to do it now?</source>
        <translation>Henüz izlenecek herhangi bir e-posta klasörü yapılandırmadınız. Şimdi yapmak ister misin?</translation>
    </message>
    <message>
        <source>Show Thunderbird</source>
        <translation>Thunderbird Göster</translation>
    </message>
    <message>
        <source>Hide Thunderbird</source>
        <translation>Thunderbird Gizle</translation>
    </message>
    <message>
        <source>New Email</source>
        <translation>Yeni E-posta</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation>Boş</translation>
    </message>
    <message>
        <source>New Email Message</source>
        <translation>Yeni E-posta Mesajı</translation>
    </message>
    <message>
        <source>5 minutes</source>
        <translation>5 dakika</translation>
    </message>
    <message>
        <source>10 minutes</source>
        <translation>10 dakika</translation>
    </message>
    <message>
        <source>30 minutes</source>
        <translation>30 dakika</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation>1 saat</translation>
    </message>
    <message>
        <source>4 hours</source>
        <translation>4 saat</translation>
    </message>
    <message>
        <source>Snooze for ...</source>
        <translation>Ertele ...</translation>
    </message>
    <message>
        <source>Unsnooze</source>
        <translation>Ertelemeyi iptal et</translation>
    </message>
    <message>
        <source>Ignore unread emails</source>
        <translation>Okunmamış e-postaları yoksay</translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation>Ayarlar...</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <source>Cannot start Thunderbird</source>
        <translation>Thunderbird başlatılamıyor</translation>
    </message>
    <message>
        <source>Error starting Thunderbird, because we could not attach to the updater:

%1</source>
        <translation>Thunderbird başlatılırken hata oluştu, çünkü güncelleyiciye ekleyemedik:

%1</translation>
    </message>
    <message>
        <source>Ignore unread emails (now %1)</source>
        <translation>Okunmamış e-postaları yoksay (şimdi %1)</translation>
    </message>
    <message>
        <source>Error starting Thunderbird as &apos;%1 %2&apos;:

%3</source>
        <translation>Thunderbird &apos;%1 %2&apos; olarak başlatılırken hata oluştu:

%3</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>Uyarı: %1</translation>
    </message>
    <message>
        <source>Don&apos;t ask again</source>
        <translation>Bir daha sorma</translation>
    </message>
</context>
<context>
    <name>UnreadMonitor</name>
    <message>
        <source>Unable to watch %1 for changes.</source>
        <translation>Değişiklikler için %1 izlenemiyor.</translation>
    </message>
    <message>
        <source>Unable to read from %1.</source>
        <translation>%1 okunamıyor.</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation>Birdtray Güncellemesi</translation>
    </message>
    <message>
        <source>Current version:</source>
        <translation>Şimdiki sürüm:</translation>
    </message>
    <message>
        <source>A new version of Birdtray is available.</source>
        <translation>Birdtray&apos;in yeni bir sürümü mevcut.</translation>
    </message>
    <message>
        <source>New version:</source>
        <translation>Yeni sürüm:</translation>
    </message>
    <message>
        <source>Download size:</source>
        <translation>İndirme boyutu:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <source>Ignore this version</source>
        <translation>Bu sürümü yok say</translation>
    </message>
    <message>
        <source>ca. %1 Mb</source>
        <translation>%1 Mb</translation>
    </message>
    <message>
        <source>Update and restart</source>
        <translation>Güncelle ve Yeniden Başlat</translation>
    </message>
</context>
<context>
    <name>UpdateDownloadDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation>Birdtray Güncellemesi</translation>
    </message>
    <message>
        <source>Downloading Birdtray update...</source>
        <translation>Birdtray güncellemesi indiriliyor...</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Arka plân</translation>
    </message>
    <message>
        <source>Downloading Birdtray installer...</source>
        <translation>Birdtray yükleyicisi indiriliyor ...</translation>
    </message>
    <message>
        <source>Download finished. Restart and update Birdtray?</source>
        <translation>İndirme tamamlandı. Birdtray yeniden başlatılsın ve güncellensin mi?</translation>
    </message>
    <message>
        <source>Downloading Birdtray installer... (%1 Mb / %2 Mb).</source>
        <translation>Birdtray yükleyicisi indiriliyor... (%1 Mb / %2 Mb).</translation>
    </message>
</context>
</TS>
